pub struct BlockBuilder;Expand description
The BlockBuilder api trait that provides the required functionality for building a block.
Implementations
Sourceimpl BlockBuilder
impl BlockBuilder
Sourcepub fn apply_extrinsic(
&self,
extrinsic: Extrinsic,
) -> StaticPayload<(Extrinsic,), Output>
pub fn apply_extrinsic( &self, extrinsic: Extrinsic, ) -> StaticPayload<(Extrinsic,), Output>
Apply the given extrinsic.
Returns an inclusion outcome which specifies if this extrinsic is included in this block or not.
Sourcepub fn finalize_block(&self) -> StaticPayload<(), Output>
pub fn finalize_block(&self) -> StaticPayload<(), Output>
Finish the current block.
Sourcepub fn inherent_extrinsics(
&self,
inherent: Inherent,
) -> StaticPayload<(Inherent,), Output>
pub fn inherent_extrinsics( &self, inherent: Inherent, ) -> StaticPayload<(Inherent,), Output>
Generate inherent extrinsics. The inherent data will vary from chain to chain.
Sourcepub fn check_inherents(
&self,
block: Block,
data: Data,
) -> StaticPayload<(Block, Data), Output>
pub fn check_inherents( &self, block: Block, data: Data, ) -> StaticPayload<(Block, Data), Output>
Check that the inherents are valid. The inherent data will vary from chain to chain.