pub struct Metadata;Expand description
The Metadata api trait that returns metadata for the runtime.
Implementations
Sourceimpl Metadata
impl Metadata
Sourcepub fn metadata(&self) -> StaticPayload<(), Output>
pub fn metadata(&self) -> StaticPayload<(), Output>
Returns the metadata of a runtime.
Sourcepub fn metadata_at_version(
&self,
version: Version,
) -> StaticPayload<(Version,), Output>
pub fn metadata_at_version( &self, version: Version, ) -> StaticPayload<(Version,), Output>
Returns the metadata at a given version.
If the given version isn’t supported, this will return None.
Use Self::metadata_versions to find out about supported metadata version of the runtime.
Sourcepub fn metadata_versions(&self) -> StaticPayload<(), Output>
pub fn metadata_versions(&self) -> StaticPayload<(), Output>
Returns the supported metadata versions.
This can be used to call metadata_at_version.