pub struct DecodedItem {
pub content_type: ContentType,
pub title: Option<String>,
pub body: Option<String>,
pub language: Option<String>,
pub image: Option<ImageSpec>,
pub profile: Option<ProfileSpec>,
}Expand description
The decoded, field-extracted view of an item (what a read tool returns).
Fields
content_type: ContentTypeThe type inferred from the present marker/profile mixins.
title: Option<String>body: Option<String>language: Option<String>image: Option<ImageSpec>profile: Option<ProfileSpec>Trait Implementations
Sourceimpl Clone for DecodedItem
impl Clone for DecodedItem
Sourcefn clone(&self) -> DecodedItem
fn clone(&self) -> DecodedItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecodedItem
impl Debug for DecodedItem
Sourceimpl Default for DecodedItem
impl Default for DecodedItem
Sourcefn default() -> DecodedItem
fn default() -> DecodedItem
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DecodedItem
impl<'de> Deserialize<'de> for DecodedItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DecodedItem
Sourceimpl JsonSchema for DecodedItem
impl JsonSchema for DecodedItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DecodedItem
impl PartialEq for DecodedItem
Sourceimpl Serialize for DecodedItem
impl Serialize for DecodedItem
impl StructuralPartialEq for DecodedItem