pub struct ImageSpec {
pub filename: String,
pub filesize: u64,
pub digest_hex: String,
pub width: u32,
pub height: u32,
pub mipmap_levels: Vec<MipmapLevel>,
}Expand description
Structured image reference carried in an item.
Fields
filename: Stringfilesize: u64digest_hex: Stringsha2-256 digest hex (0x-prefixed) of the full-resolution image.
width: u32height: u32mipmap_levels: Vec<MipmapLevel>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ImageSpec
impl<'de> Deserialize<'de> for ImageSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ImageSpec
Sourceimpl JsonSchema for ImageSpec
impl JsonSchema for ImageSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ImageSpec