pub struct ProfileSpec {
pub account_type: i32,
pub location: String,
}Expand description
Structured profile fields.
Fields
account_type: i32Account type (0..=8, see AccountType).
location: StringTrait Implementations
Sourceimpl Clone for ProfileSpec
impl Clone for ProfileSpec
Sourceimpl Debug for ProfileSpec
impl Debug for ProfileSpec
Sourceimpl Default for ProfileSpec
impl Default for ProfileSpec
Sourceimpl<'de> Deserialize<'de> for ProfileSpec
impl<'de> Deserialize<'de> for ProfileSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProfileSpec
Sourceimpl JsonSchema for ProfileSpec
impl JsonSchema for ProfileSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProfileSpec
impl PartialEq for ProfileSpec
Sourceimpl Serialize for ProfileSpec
impl Serialize for ProfileSpec
impl StructuralPartialEq for ProfileSpec